@@ -1,19 +1,21 @@
-from eliot._message import WrittenMessage
-from six import BytesIO, StringIO, text_type
-from termcolor import colored
+import time
+from eliot.parse import WrittenMessage
+from six import StringIO, text_type
 from testtools import ExpectedException, TestCase
 from testtools.matchers import AfterPreprocessing as After
 from testtools.matchers import (
-    Contains, EndsWith, Equals, HasLength, IsDeprecated, MatchesAll,
-    MatchesListwise, StartsWith)
+    Contains, Equals, HasLength, MatchesAll, MatchesListwise, StartsWith)
 
 from eliottree import (
-    Tree, render_task_nodes, render_tasks, tasks_from_iterable)
+    render_tasks, tasks_from_iterable)
+from eliottree._color import colored
 from eliottree._render import (
-    COLORS, RIGHT_DOUBLE_ARROW, _default_value_formatter, _no_color,
-    format_node, get_children, message_fields, message_name)
+    _default_value_formatter, format_node,
+    get_children, message_fields, message_name)
+from eliottree.tree_format._text import (
+    HOURGLASS, RIGHT_DOUBLE_ARROW, Options)
+from eliottree._theme import get_theme
 from eliottree._util import eliot_ns
-from eliottree.render import get_name_factory
 from eliottree.test.matchers import ExactlyEquals
 from eliottree.test.tasks import (
     action_task, action_task_end, action_task_end_failed, dict_action_task,
@@ -81,6 +83,22 @@ class DefaultValueFormatterTests(TestCase):
             human_readable=True, field_limit=0)
         # datetime(2015, 6, 6, 22, 57, 12)
         now = 1433631432
+        self.assertThat(
+            format_value(now, eliot_ns(u'timestamp')),
+            ExactlyEquals(u'2015-06-06 22:57:12Z'))
+        self.assertThat(
+            format_value(str(now), eliot_ns(u'timestamp')),
+            ExactlyEquals(u'2015-06-06 22:57:12Z'))
+
+    def test_timestamp_field_local(self):
+        """
+        Format Eliot ``timestamp`` fields as human-readable local time if the
+        feature was requested.
+        """
+        format_value = _default_value_formatter(
+            human_readable=True, field_limit=0, utc_timestamps=False)
+        # datetime(2015, 6, 6, 22, 57, 12)
+        now = 1433631432 + time.timezone
         self.assertThat(
             format_value(now, eliot_ns(u'timestamp')),
             ExactlyEquals(u'2015-06-06 22:57:12'))
@@ -116,379 +134,12 @@ class DefaultValueFormatterTests(TestCase):
             ExactlyEquals(text_type(now)))
 
 
-class RenderTaskNodesTests(TestCase):
-    """
-    Tests for ``eliottree.render.render_task_nodes``.
-    """
-    def test_deprecated(self):
-        """
-        `render_task_nodes` is deprecated.
-        """
-        self.assertThat(
-            lambda: render_task_nodes(lambda: None, [], field_limit=0),
-            IsDeprecated(Contains('render_task_nodes is deprecated')))
-
-    def test_tasks(self):
-        """
-        Render two tasks of sequential levels, by default most standard Eliot
-        task keys are ignored.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([action_task, action_task_end])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=0)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action@1/started\n'
-                u'    \u251c\u2500\u2500 timestamp: 1425356800\n'
-                u'    \u2514\u2500\u2500 app:action@2/succeeded\n'
-                u'        \u2514\u2500\u2500 timestamp: 1425356800\n\n'
-                .encode('utf-8')))
-
-    def test_tasks_human_readable(self):
-        """
-        Render two tasks of sequential levels, by default most standard Eliot
-        task keys are ignored, values are formatted to be human readable.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([action_task, action_task_end])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=0,
-            human_readable=True)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action@1/started\n'
-                u'    \u251c\u2500\u2500 timestamp: 2015-03-03 04:26:40\n'
-                u'    \u2514\u2500\u2500 app:action@2/succeeded\n'
-                u'        \u2514\u2500\u2500 timestamp: 2015-03-03 04:26:40\n'
-                u'\n'
-                .encode('utf-8')))
-
-    def test_multiline_field(self):
-        """
-        When no field limit is specified for task values, multiple lines are
-        output for multiline tasks.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([multiline_action_task])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=0)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action@1/started\n'
-                u'    \u251c\u2500\u2500 message: this is a\u23ce\n'
-                u'    \u2502   many line message\n'
-                u'    \u2514\u2500\u2500 timestamp: 1425356800\n\n'
-                .encode('utf-8')))
-
-    def test_multiline_field_limit(self):
-        """
-        When a field limit is specified for task values, only the first of
-        multiple lines is output.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([multiline_action_task])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=1000)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action@1/started\n'
-                u'    \u251c\u2500\u2500 message: this is a\u2026\n'
-                u'    \u2514\u2500\u2500 timestamp: 1425356800\n\n'
-                .encode('utf-8')))
-
-    def test_field_limit(self):
-        """
-        Truncate task values that are longer than the field_limit if specified.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([message_task])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=5)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'cdeb220d-7605-4d5f-8341-1a170222e308\n'
-                u'\u2514\u2500\u2500 twisted:log@1\n'
-                u'    \u251c\u2500\u2500 error: False\n'
-                u'    \u251c\u2500\u2500 message: Main \u2026\n'
-                u'    \u2514\u2500\u2500 timestamp: 14253\u2026\n\n'
-                .encode('utf-8')))
-
-    def test_ignored_keys(self):
-        """
-        Task keys can be ignored.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([action_task])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=0,
-            ignored_task_keys=set(['task_level']))
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action@1/started\n'
-                u'    \u251c\u2500\u2500 action_status: started\n'
-                u'    \u251c\u2500\u2500 action_type: app:action\n'
-                u'    \u251c\u2500\u2500 task_uuid: '
-                u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'    \u2514\u2500\u2500 timestamp: 1425356800\n\n'
-                .encode('utf-8')))
-
-    def test_task_data(self):
-        """
-        Task data is rendered as tree elements.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([message_task])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=0)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'cdeb220d-7605-4d5f-8341-1a170222e308\n'
-                u'\u2514\u2500\u2500 twisted:log@1\n'
-                u'    \u251c\u2500\u2500 error: False\n'
-                u'    \u251c\u2500\u2500 message: Main loop terminated.\n'
-                u'    \u2514\u2500\u2500 timestamp: 1425356700\n\n'
-                .encode('utf-8')))
-
-    def test_dict_data(self):
-        """
-        Task values that are ``dict``s are rendered as tree elements.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([dict_action_task])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=0)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action@1/started\n'
-                u'    \u251c\u2500\u2500 some_data\n'
-                u'    \u2502   \u2514\u2500\u2500 a: 42\n'
-                u'    \u2514\u2500\u2500 timestamp: 1425356800\n\n'
-                .encode('utf-8')))
-
-    def test_nested(self):
-        """
-        Render nested tasks in a way that visually represents that nesting.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([action_task, nested_action_task])
-        render_task_nodes(fd.write, tree.nodes(), 0)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action@1/started\n'
-                u'    \u251c\u2500\u2500 timestamp: 1425356800\n'
-                u'    \u2514\u2500\u2500 app:action:nest@1,1/started\n'
-                u'        \u2514\u2500\u2500 timestamp: 1425356900\n\n'
-                .encode('utf-8')))
-
-    def test_janky_message(self):
-        """
-        Task names, UUIDs, keys and values in messages all have control
-        characters escaped.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([janky_message_task])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=0)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'cdeb220d-7605-4d5f-\u241b(08341-1a170222e308\n'
-                u'\u2514\u2500\u2500 M\u241b(0@1\n'
-                u'    \u251c\u2500\u2500 er\u241bror: False\n'
-                u'    \u251c\u2500\u2500 mes\u240asage: '
-                u'Main loop\u241b(0terminated.\n'
-                u'    \u2514\u2500\u2500 timestamp: 1425356700\n\n'
-                .encode('utf-8')))
-
-    def test_janky_action(self):
-        """
-        Task names, UUIDs, keys and values in actions all have control
-        characters escaped.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([janky_action_task])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=0)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'f3a32bb3-ea6b-457c-\u241b(0aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 A\u241b(0@1/started\n'
-                u'    \u251c\u2500\u2500 \u241b(0\n'
-                u'    \u2502   \u2514\u2500\u2500 \u241b(0: nope\n'
-                u'    \u251c\u2500\u2500 mes\u240asage: hello\u241b(0world\n'
-                u'    \u2514\u2500\u2500 timestamp: 1425356800\u241b(0\n\n'
-                .encode('utf-8')))
-
-    def test_colorize(self):
-        """
-        Passing ``colorize=True`` will colorize the output.
-        """
-        fd = BytesIO()
-        tree = Tree()
-        tree.merge_tasks([action_task, action_task_end])
-        render_task_nodes(
-            write=fd.write,
-            nodes=tree.nodes(),
-            field_limit=0,
-            colorize=True)
-        C = COLORS(colored)
-        self.assertThat(
-            fd.getvalue(),
-            ExactlyEquals(
-                u'\n'.join([
-                    C.root(u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4'),
-                    u'\u2514\u2500\u2500 {}'.format(
-                        C.success(u'app:action@1/started')),
-                    u'    \u251c\u2500\u2500 {}: {}'.format(
-                        C.prop(u'timestamp'), u'1425356800'),
-                    u'    \u2514\u2500\u2500 {}'.format(
-                        C.success(u'app:action@2/succeeded')),
-                    u'        \u2514\u2500\u2500 {}: {}'.format(
-                        C.prop('timestamp'), u'1425356800'),
-                    u'\n',
-                ]).encode('utf-8')))
+colors = get_theme(dark_background=True, colored=colored)
+no_colors = get_theme(dark_background=True, colored=None)
 
 
-class GetNameFactoryTests(TestCase):
-    """
-    Tests for `eliottree.render.get_name_factory` output.
-    """
-    def test_text(self):
-        """
-        Text leaves are their own name.
-        """
-        get_name = get_name_factory(None)
-        self.assertThat(
-            get_name(u'hello'),
-            ExactlyEquals(u'hello'))
-        self.assertThat(
-            get_name(u'hello\x1b'),
-            ExactlyEquals(u'hello\u241b'))
-
-    def test_tuple_dict(self):
-        """
-        Tuples whose value is a dict use the name in the first position of the
-        tuple.
-        """
-        get_name = get_name_factory(None)
-        self.assertThat(
-            get_name((u'key\x1bname', {})),
-            ExactlyEquals(u'key\u241bname'))
-
-    def test_tuple_unicode(self):
-        """
-        Tuples whose value is unicode are a key/value pair.
-        """
-        C = COLORS(colored)
-        get_name = get_name_factory(C)
-        self.assertThat(
-            get_name((u'key\x1bname', u'hello')),
-            ExactlyEquals(u'{}: hello'.format(C.prop(u'key\u241bname'))))
-
-    def test_tuple_root(self):
-        """
-        Tuples that are neither unicode nor a dict are assumed to be a root
-        node.
-        """
-        C = COLORS(colored)
-        get_name = get_name_factory(C)
-        self.assertThat(
-            get_name((u'key\x1bname', None)),
-            ExactlyEquals(C.root(u'key\u241bname')))
-
-    def test_node(self):
-        """
-        Task nodes use their own name.
-        """
-        tree = Tree()
-        tree.merge_tasks([action_task])
-        node = tree.nodes()[0][1]
-        C = COLORS(colored)
-        get_name = get_name_factory(C)
-        self.assertThat(
-            get_name(node),
-            ExactlyEquals(node.name))
-
-    def test_node_success(self):
-        """
-        Task nodes indicating success are colored.
-        """
-        tree = Tree()
-        tree.merge_tasks([action_task])
-        node = tree.nodes()[0][1].copy()
-        node.success = True
-        C = COLORS(colored)
-        get_name = get_name_factory(C)
-        self.assertThat(
-            get_name(node),
-            ExactlyEquals(C.success(node.name)))
-
-    def test_node_failure(self):
-        """
-        Task nodes indicating failure are colored.
-        """
-        tree = Tree()
-        tree.merge_tasks([action_task])
-        node = tree.nodes()[0][1].copy()
-        node.success = False
-        C = COLORS(colored)
-        get_name = get_name_factory(C)
-        self.assertThat(
-            get_name(node),
-            ExactlyEquals(C.failure(node.name)))
-
-
-colors = COLORS(colored)
-no_colors = COLORS(_no_color)
+def no_formatting(value, field_name=None):
+    return text_type(value)
 
 
 class MessageNameTests(TestCase):
@@ -501,7 +152,7 @@ class MessageNameTests(TestCase):
         """
         message = next(tasks_from_iterable([action_task])).root().start_message
         self.assertThat(
-            message_name(colors, message),
+            message_name(colors, no_formatting, message, options=Options()),
             StartsWith(colors.parent(message.contents.action_type)))
 
     def test_action_task_level(self):
@@ -510,7 +161,7 @@ class MessageNameTests(TestCase):
         """
         message = next(tasks_from_iterable([action_task])).root().start_message
         self.assertThat(
-            message_name(colors, message),
+            message_name(colors, no_formatting, message, options=Options()),
             Contains(message.task_level.to_string()))
 
     def test_action_status(self):
@@ -519,8 +170,8 @@ class MessageNameTests(TestCase):
         """
         message = next(tasks_from_iterable([action_task])).root().start_message
         self.assertThat(
-            message_name(colors, message),
-            EndsWith(u'started'))
+            message_name(colors, no_formatting, message, options=Options()),
+            Contains(u'started'))
 
     def test_action_status_success(self):
         """
@@ -530,8 +181,8 @@ class MessageNameTests(TestCase):
             action_task, action_task_end,
         ])).root().end_message
         self.assertThat(
-            message_name(colors, message),
-            EndsWith(colors.success(u'succeeded')))
+            message_name(colors, no_formatting, message, options=Options()),
+            Contains(colors.status_success(u'succeeded')))
 
     def test_action_status_failed(self):
         """
@@ -541,8 +192,8 @@ class MessageNameTests(TestCase):
             action_task, action_task_end_failed,
         ])).root().end_message
         self.assertThat(
-            message_name(colors, message),
-            EndsWith(colors.failure(u'failed')))
+            message_name(colors, no_formatting, message, options=Options()),
+            Contains(colors.status_failure(u'failed')))
 
     def test_message_type(self):
         """
@@ -550,7 +201,7 @@ class MessageNameTests(TestCase):
         """
         message = WrittenMessage.from_dict(message_task)
         self.assertThat(
-            message_name(colors, message),
+            message_name(colors, no_formatting, message, options=Options()),
             StartsWith(colors.parent(message.contents.message_type)))
 
     def test_message_task_level(self):
@@ -559,7 +210,7 @@ class MessageNameTests(TestCase):
         """
         message = WrittenMessage.from_dict(message_task)
         self.assertThat(
-            message_name(colors, message),
+            message_name(colors, no_formatting, message, options=Options()),
             Contains(message.task_level.to_string()))
 
     def test_unknown(self):
@@ -568,11 +219,11 @@ class MessageNameTests(TestCase):
         ``<unnamed>``.
         """
         self.assertThat(
-            message_name(colors, None),
+            message_name(colors, no_formatting, None, options=Options()),
             ExactlyEquals(u'<unnamed>'))
-        message = WrittenMessage.from_dict({})
+        message = WrittenMessage.from_dict({u'timestamp': 0})
         self.assertThat(
-            message_name(colors, message),
+            message_name(colors, no_formatting, message, options=Options()),
             ExactlyEquals(u'<unnamed>'))
 
 
@@ -582,9 +233,9 @@ class FormatNodeTests(TestCase):
     """
     def format_node(self, node, format_value=None, colors=no_colors):
         if format_value is None:
-            def format_value(value, _):
+            def format_value(value, field_name=None):
                 return value
-        return format_node(format_value, colors, node)
+        return format_node(format_value, colors, Options(), node)
 
     def test_task(self):
         """
@@ -599,14 +250,17 @@ class FormatNodeTests(TestCase):
         """
         `WrittenAction`'s start message is rendered.
         """
-        node = next(tasks_from_iterable([action_task])).root()
+        tasks = tasks_from_iterable([action_task, action_task_end])
+        node = next(tasks).root()
         self.assertThat(
             self.format_node(node),
-            ExactlyEquals(u'{}{} {} {}'.format(
+            ExactlyEquals(u'{}{} {} {} {} \u29d6 {}'.format(
                 node.start_message.contents.action_type,
                 node.start_message.task_level.to_string(),
                 RIGHT_DOUBLE_ARROW,
-                node.start_message.contents.action_status)))
+                node.start_message.contents.action_status,
+                node.start_message.timestamp,
+                node.end_message.timestamp - node.start_message.timestamp)))
 
     def test_tuple_list(self):
         """
@@ -616,8 +270,9 @@ class FormatNodeTests(TestCase):
         node = (u'a\nb\x1bc', [u'x\n', u'y\x1b', u'z'])
         self.assertThat(
             self.format_node(node, colors=colors),
-            ExactlyEquals(u'{}: '.format(
-                colors.prop(u'a\u240ab\u241bc'))))
+            ExactlyEquals(u'{}: {}'.format(
+                colors.prop_key(u'a\u240ab\u241bc'),
+                colors.prop_value(u''))))
 
     def test_tuple_dict(self):
         """
@@ -627,8 +282,9 @@ class FormatNodeTests(TestCase):
         node = (u'a\nb\x1bc', {u'x\n': u'y\x1b', u'z': u'zz'})
         self.assertThat(
             self.format_node(node, colors=colors),
-            ExactlyEquals(u'{}: '.format(
-                colors.prop(u'a\u240ab\u241bc'))))
+            ExactlyEquals(u'{}: {}'.format(
+                colors.prop_key(u'a\u240ab\u241bc'),
+                colors.prop_value(u''))))
 
     def test_tuple_other(self):
         """
@@ -638,15 +294,15 @@ class FormatNodeTests(TestCase):
         self.assertThat(
             self.format_node(node, colors=colors),
             ExactlyEquals(u'{}: {}'.format(
-                colors.prop(u'a\u240ab\u241bc'),
-                u'hello')))
+                colors.prop_key(u'a\u240ab\u241bc'),
+                colors.prop_value(u'hello'))))
 
         node = (u'a\nb\x1bc', 42)
         self.assertThat(
             self.format_node(node, colors=colors),
             ExactlyEquals(u'{}: {}'.format(
-                colors.prop(u'a\u240ab\u241bc'),
-                42)))
+                colors.prop_key(u'a\u240ab\u241bc'),
+                colors.prop_value(u'42'))))
 
     def test_other(self):
         """
@@ -675,7 +331,7 @@ class MessageFieldsTests(TestCase):
 
     def test_fields(self):
         """
-        Include all the message fields and the timestamp.
+        Include all the message fields but not the timestamp.
         """
         message = WrittenMessage.from_dict({u'a': 1})
         self.assertThat(
@@ -685,8 +341,7 @@ class MessageFieldsTests(TestCase):
         self.assertThat(
             message_fields(message, set()),
             Equals([
-                (u'a', 1),
-                (eliot_ns(u'timestamp'), 12345678)]))
+                (u'a', 1)]))
 
     def test_ignored_fields(self):
         """
@@ -727,8 +382,7 @@ class GetChildrenTests(TestCase):
             list(get_children({u'c'}, node)),
             Equals([
                 (u'action_status', start_message.contents.action_status),
-                (u'action_type', start_message.contents.action_type),
-                (eliot_ns(u'timestamp'), start_message.timestamp)]))
+                (u'action_type', start_message.contents.action_type)]))
 
     def test_written_action_start(self):
         """
@@ -739,11 +393,10 @@ class GetChildrenTests(TestCase):
             action_task, nested_action_task, action_task_end])).root()
         start_message = node.start_message
         self.assertThat(
-            list(get_children({u'foo'}, node))[:3],
+            list(get_children({u'foo'}, node))[:2],
             Equals([
                 (u'action_status', start_message.contents.action_status),
-                (u'action_type', start_message.contents.action_type),
-                (eliot_ns(u'timestamp'), start_message.timestamp)]))
+                (u'action_type', start_message.contents.action_type)]))
 
     def test_written_action_children(self):
         """
@@ -752,7 +405,7 @@ class GetChildrenTests(TestCase):
         node = next(tasks_from_iterable([
             action_task, nested_action_task, action_task_end])).root()
         self.assertThat(
-            list(get_children({u'foo'}, node))[3],
+            list(get_children({u'foo'}, node))[2],
             Equals(node.children[0]))
 
     def test_written_action_no_children(self):
@@ -763,7 +416,7 @@ class GetChildrenTests(TestCase):
         node = next(tasks_from_iterable([action_task])).root()
         self.assertThat(
             list(get_children({u'foo'}, node)),
-            HasLength(3))
+            HasLength(2))
 
     def test_written_action_no_end(self):
         """
@@ -782,12 +435,12 @@ class GetChildrenTests(TestCase):
         node = next(tasks_from_iterable([
             action_task, nested_action_task, action_task_end])).root()
         self.assertThat(
-            list(get_children({u'foo'}, node))[4:],
+            list(get_children({u'foo'}, node))[3:],
             Equals([node.end_message]))
 
     def test_written_message(self):
         """
-        The fields of `WrittenMessage`\s are their children. Fields can also be
+        The fields of `WrittenMessage`\\s are their children. Fields can also be
         ignored.
         """
         node = WrittenMessage.from_dict({u'a': 1, u'b': 2, u'c': 3})
@@ -889,10 +542,10 @@ class RenderTasksTests(TestCase):
             self.render_tasks([action_task, action_task_end]),
             ExactlyEquals(
                 u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action/1 \u21d2 started\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 1425356800\n'
-                u'    \u2514\u2500\u2500 app:action/2 \u21d2 succeeded\n'
-                u'        \u2514\u2500\u2500 eliot/timestamp: 1425356800\n\n'))
+                u'\u2514\u2500\u2500 app:action/1 \u21d2 started '
+                u'1425356800 \u29d6 2\n'
+                u'    \u2514\u2500\u2500 app:action/2 \u21d2 succeeded '
+                u'1425356802\n\n'))
 
     def test_tasks_human_readable(self):
         """
@@ -904,12 +557,10 @@ class RenderTasksTests(TestCase):
                               human_readable=True),
             ExactlyEquals(
                 u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action/1 \u21d2 started\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: '
-                u'2015-03-03 04:26:40\n'
-                u'    \u2514\u2500\u2500 app:action/2 \u21d2 succeeded\n'
-                u'        \u2514\u2500\u2500 eliot/timestamp: '
-                u'2015-03-03 04:26:40\n'
+                u'\u2514\u2500\u2500 app:action/1 \u21d2 started '
+                u'2015-03-03 04:26:40Z \u29d6 2.000s\n'
+                u'    \u2514\u2500\u2500 app:action/2 \u21d2 succeeded '
+                u'2015-03-03 04:26:42Z\n'
                 u'\n'))
 
     def test_multiline_field(self):
@@ -926,8 +577,8 @@ class RenderTasksTests(TestCase):
             fd.getvalue(),
             ExactlyEquals(
                 u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action/1 \u21d2 started\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 1425356800\n'
+                u'\u2514\u2500\u2500 app:action/1 \u21d2 started '
+                u'1425356800\n'
                 u'    \u2514\u2500\u2500 message: this is a\u23ce\n'
                 u'        many line message\n\n'))
 
@@ -941,8 +592,8 @@ class RenderTasksTests(TestCase):
                               field_limit=1000),
             ExactlyEquals(
                 u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action/1 \u21d2 started\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 1425356800\n'
+                u'\u2514\u2500\u2500 app:action/1 \u21d2 started '
+                u'1425356800\n'
                 u'    \u2514\u2500\u2500 message: this is a\u2026\n\n'))
 
     def test_field_limit(self):
@@ -954,8 +605,8 @@ class RenderTasksTests(TestCase):
                               field_limit=5),
             ExactlyEquals(
                 u'cdeb220d-7605-4d5f-8341-1a170222e308\n'
-                u'\u2514\u2500\u2500 twisted:log/1\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 14253\u2026\n'
+                u'\u2514\u2500\u2500 twisted:log/1 '
+                u'14253\u2026\n'
                 u'    \u251c\u2500\u2500 error: False\n'
                 u'    \u2514\u2500\u2500 message: Main \u2026\n\n'))
 
@@ -968,9 +619,9 @@ class RenderTasksTests(TestCase):
                               ignored_fields={u'action_type'}),
             ExactlyEquals(
                 u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action/1 \u21d2 started\n'
-                u'    \u251c\u2500\u2500 action_status: started\n'
-                u'    \u2514\u2500\u2500 eliot/timestamp: 1425356800\n\n'))
+                u'\u2514\u2500\u2500 app:action/1 \u21d2 started '
+                u'1425356800\n'
+                u'    \u2514\u2500\u2500 action_status: started\n\n'))
 
     def test_task_data(self):
         """
@@ -980,8 +631,8 @@ class RenderTasksTests(TestCase):
             self.render_tasks([message_task]),
             ExactlyEquals(
                 u'cdeb220d-7605-4d5f-8341-1a170222e308\n'
-                u'\u2514\u2500\u2500 twisted:log/1\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 1425356700\n'
+                u'\u2514\u2500\u2500 twisted:log/1 '
+                u'1425356700\n'
                 u'    \u251c\u2500\u2500 error: False\n'
                 u'    \u2514\u2500\u2500 message: Main loop terminated.\n\n'))
 
@@ -993,8 +644,8 @@ class RenderTasksTests(TestCase):
             self.render_tasks([dict_action_task]),
             ExactlyEquals(
                 u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action/1 \u21d2 started\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 1425356800\n'
+                u'\u2514\u2500\u2500 app:action/1 \u21d2 started '
+                u'1425356800\n'
                 u'    \u2514\u2500\u2500 some_data: \n'
                 u'        \u2514\u2500\u2500 a: 42\n\n'))
 
@@ -1006,8 +657,8 @@ class RenderTasksTests(TestCase):
             self.render_tasks([list_action_task]),
             ExactlyEquals(
                 u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action/1 \u21d2 started\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 1425356800\n'
+                u'\u2514\u2500\u2500 app:action/1 \u21d2 started '
+                u'1425356800\n'
                 u'    \u2514\u2500\u2500 some_data: \n'
                 u'        \u251c\u2500\u2500 0: a\n'
                 u'        \u2514\u2500\u2500 1: b\n\n'))
@@ -1020,10 +671,10 @@ class RenderTasksTests(TestCase):
             self.render_tasks([action_task, nested_action_task]),
             ExactlyEquals(
                 u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 app:action/1 \u21d2 started\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 1425356800\n'
-                u'    \u2514\u2500\u2500 app:action:nest/1/1 \u21d2 started\n'
-                u'        \u2514\u2500\u2500 eliot/timestamp: 1425356900\n\n'))
+                u'\u2514\u2500\u2500 app:action/1 \u21d2 started '
+                u'1425356800\n'
+                u'    \u2514\u2500\u2500 app:action:nest/1/1 \u21d2 started '
+                u'1425356900\n\n'))
 
     def test_janky_message(self):
         """
@@ -1034,8 +685,8 @@ class RenderTasksTests(TestCase):
             self.render_tasks([janky_message_task]),
             ExactlyEquals(
                 u'cdeb220d-7605-4d5f-\u241b(08341-1a170222e308\n'
-                u'\u2514\u2500\u2500 M\u241b(0/1\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 1425356700\n'
+                u'\u2514\u2500\u2500 M\u241b(0/1 '
+                u'1425356700\n'
                 u'    \u251c\u2500\u2500 er\u241bror: False\n'
                 u'    \u2514\u2500\u2500 mes\u240asage: '
                 u'Main loop\u241b(0terminated.\n\n'))
@@ -1049,32 +700,34 @@ class RenderTasksTests(TestCase):
             self.render_tasks([janky_action_task]),
             ExactlyEquals(
                 u'f3a32bb3-ea6b-457c-\u241b(0aa99-08a3d0491ab4\n'
-                u'\u2514\u2500\u2500 A\u241b(0/1 \u21d2 started\n'
+                u'\u2514\u2500\u2500 A\u241b(0/1 \u21d2 started '
+                u'1425356800\u241b(0\n'
                 u'    \u251c\u2500\u2500 \u241b(0: \n'
                 u'    \u2502   \u2514\u2500\u2500 \u241b(0: nope\n'
-                u'    \u251c\u2500\u2500 eliot/timestamp: 1425356800\u241b(0\n'
                 u'    \u2514\u2500\u2500 mes\u240asage: hello\u241b(0world\n\n'
             ))
 
     def test_colorize(self):
         """
-        Passing ``colorize=True`` will colorize the output.
+        Passing ``theme`` will colorize the output.
         """
         self.assertThat(
             self.render_tasks([action_task, action_task_end],
-                              colorize=True),
+                              theme=colors),
             ExactlyEquals(
                 u'\n'.join([
                     colors.root(u'f3a32bb3-ea6b-457c-aa99-08a3d0491ab4'),
-                    u'\u2514\u2500\u2500 {}/1 \u21d2 {}'.format(
+                    u'\u2514\u2500\u2500 {}{} \u21d2 {} {} {} {}'.format(
                         colors.parent(u'app:action'),
-                        colors.success(u'started')),
-                    u'    \u251c\u2500\u2500 {}: {}'.format(
-                        colors.prop(u'eliot/timestamp'), u'1425356800'),
-                    u'    \u2514\u2500\u2500 {}/2 \u21d2 {}'.format(
+                        colors.task_level(u'/1'),
+                        colors.status_success(u'started'),
+                        colors.timestamp(u'1425356800'),
+                        HOURGLASS,
+                        colors.duration(u'2')),
+                    u'    \u2514\u2500\u2500 {}{} \u21d2 {} {}'.format(
                         colors.parent(u'app:action'),
-                        colors.success(u'succeeded')),
-                    u'        \u2514\u2500\u2500 {}: {}'.format(
-                        colors.prop('eliot/timestamp'), u'1425356800'),
+                        colors.task_level(u'/2'),
+                        colors.status_success(u'succeeded'),
+                        colors.timestamp(u'1425356802')),
                     u'\n',
                 ])))
